localStorage.removeItem('seenComments_xhs');
chrome.storage.local.get(['selectedFeatureXhsdm']).then(result => {
  console.log("我的小红书弹幕采集功能开关:", result.selectedFeatureXhsdm);
});    

chrome.storage.local.get(['apikey'], (result) => {
  const savedApikey = result.apikey;
  console.log("我的apikey", savedApikey);

  // 链接评论转发专用域名的ws服务
  const ws = new WebSocket('wss://plzf.tingwu.co:8872');

  // 连接成功后发送认证信息
  ws.onopen = () => {
    ws.send(JSON.stringify({
      type: 'auth',
      apikey: result.apikey
    }));
  };

  // 接收消息
  ws.onmessage = (event) => {
    const data = JSON.parse(event.data);
    console.log('WSS收到消息:', data);
  };

  // 发送消息
  function sendMessage_ws(message) {
    if (ws.readyState === WebSocket.OPEN) {
      ws.send(JSON.stringify(message));
    }
  }

  chrome.storage.local.get(['selectedFeatureXhsdm']).then(result => {
  
    if (result.selectedFeatureXhsdm == 'xhsdm') { console.log("已开启小红书弹幕2");
      // 创建一个Set来存储已处理的弹幕
      const seenComments = new Set(JSON.parse(localStorage.getItem('seenComments_xhs') || '[]'));
       
      // 监听弹幕区变化
      const observerxhs = new MutationObserver((mutations) => {
        mutations.forEach((mutation) => {
          if (mutation.type === 'childList') {
            const newComments = mutation.target.querySelectorAll('.comments-item.message-standard');

            newComments.forEach((comment) => {
              // 获取弹幕内容
              const authorElement = comment.querySelector('.nickname');
              const contentElement = comment.querySelector('.content');

              if (!authorElement || !contentElement) return;

              const author = authorElement.textContent;
              const content = contentElement.textContent;

              // 创建唯一标识
              const commentId = `${author}-${content}`;

              // 检查是否已处理过该弹幕
              if (!seenComments.has(commentId)) {
                seenComments.add(commentId);

                // 获取当前时间
                const timestamp = new Date().toLocaleString("zh-CN", { hour12: false }).replace(/\//g, "-");


                 // 判断内容是否为"来了"
                if (content === "来了") {
                  // 构建进入直播间信息
                  const joinInfo = {
                      nickname: author,
                      user_action: "进入直播间",
                      timestamp
                  };
                  
                  // 构建数据
                  const datas = {
                      error: 0,
                      comments: [],
                      join_info: [joinInfo],
                      online_users: []
                  };

                  sendMessage_ws(datas);
              } else {
                   // 构建弹幕数据
                  const commentData = {
                    username: author,
                    content: content,
                    timestamp: timestamp,
                  };

                  // 打印弹幕数据
                  console.log('弹幕数据:', commentData);
                  const datas = {
                    error: 0,
                    comments: [commentData],
                    join_info: [],
                    online_users: []
                  };
                  // 发送到WebSocket
                  sendMessage_ws(datas);
              }


               

                // 发送到PHP接口
                const formData = new FormData();
                formData.append('type', 'comment');
                formData.append('content', content);
                formData.append('username', author);
                formData.append('timestamp', timestamp);

                fetch(`https://live2.tingwu.co/sphapi.php?action=add_comment_log_xhs&apikey=`+ savedApikey, {
                  method: 'POST',
                  body: formData
                })
                .then(response => response.json())
                .then(data => {
                  console.log('API Response:', data);
                  if (data.error === 0) {
                    updateLogArea(JSON.stringify({ type: '弹幕', username: author, content, timestamp: timestamp }, null, 2), "用户弹幕");
                  }
                })
                .catch(error => {
                  console.error('API Error:', error);
                });

                // 更新localStorage
                localStorage.setItem('seenComments_xhs', JSON.stringify([...seenComments]));
              }
            });
          }
        });
      });

      // 开始监听弹幕区
      observerxhs.observe(document.body, {
        childList: true,
        subtree: true,
      });
    }
  });
});

// 新增函数：更新 log_area 内容
function updateLogArea(log, type = "信息") { // 默认类型为 "信息"
  const logArea = document.getElementById('log_area');
  const timestamp = new Date().toLocaleString("zh-CN", { hour12: false }).replace(/\//g, "-");
  const logWithTimestamp = `[${timestamp}] [${type}] ${log}`; // 添加时间戳和类型

  // 使用 chrome.storage.local 存储日志
  chrome.storage.local.get(['logs_xhs'], (result) => {
    let logs = result.logs_xhs || [];
    // 添加新日志
    logs.unshift(logWithTimestamp);
    // 限制最多存储50条日志
    if (logs.length > 50) {
      logs = logs.slice(0, 50);
    }
    // 更新本地存储
    chrome.storage.local.set({ logs_xhs: logs }, () => {
      // 发送消息到 popup.js
      chrome.runtime.sendMessage({ type: "log_show_xhs", logs_xhs: logs });
    });
  });
}